<script setup>

import AdminAuthenticatedLayout from '@/Layouts/AdminAuthenticatedLayout.vue';
import { ref, onMounted, computed } from 'vue';
import { Head, usePage, useForm } from '@inertiajs/vue3';
import NavLink from '@/Components/NavLink.vue';

const page = usePage();
console.log(page);
const users = computed(() => page.props.users.data || []);
const loading = computed(() => page.props.loading || false);
const perPageOptions = [10, 20, 50]; // Adjust as needed
const perPage = ref(perPageOptions[0]);
const firstpage = ref(null);
const lastpage = ref(null);
const nextpage = ref(null);
const previouspage = ref(null);
const totalPages = ref(null);
const currentPage = ref(null);
const urlPerPage = ref(page.props.per_page);

const isMobile = ref(window.innerWidth <= 768);
const flashMessage = ref('');

if(perPage != urlPerPage) {
    perPage.value = urlPerPage.value;
}

defineProps({
    status: {
        type: String,
    },
    errorMsg: {
        type: String,
    },
});

const form = useForm({
    id: '',
});

const sortDirections = ref({});
const sortBy = (key) => {
  // If the key has not been sorted before, default to ascending
  if (!sortDirections.value[key]) {
    sortDirections.value[key] = 'asc';
  } else {
    // If it was ascending before, now make it descending, and vice versa
    sortDirections.value[key] = sortDirections.value[key] === 'asc' ? 'desc' : 'asc';
  }

  const direction = sortDirections.value[key];

  users.value.sort((a, b) => {
    if (a[key] < b[key]) {
      return direction === 'asc' ? -1 : 1;
    }
    if (a[key] > b[key]) {
      return direction === 'asc' ? 1 : -1;
    }
    return 0;
  });
};

const sortedUsers = computed(() => users.value);

const changePerPage = () => {
    window.location.href = getLinkUrl();
};

const getLinkUrl = () => {
  // Build the URL with the selected per page value
  return `/admin/users?per_page=${perPage.value}`;
};

const editUser = (user) => {
  window.location.href = `/admin/user/edit/${user.id}`;
};

const deleteUser = (user) => {
  const userID = user.id

  if (confirm('Are you sure you want to delete this user?')) {
    // admin.users.delete
    form.post(route('admin.users.delete',{id: userID}), {
        onSuccess: () => {
            // Update your success message or perform other actions here
            flashMessage.value = "User deleted successfully!";
        },
        onError: (error) => {
            // Handle error case here, if needed
            console.error(error);
        }
    });
  }
};

const handleResize = () => {
    isMobile.value = window.innerWidth <= 768; // Adjust the threshold as needed
}

onMounted(() => {
    const query = usePage().props;
    firstpage.value = query.users.first_page_url;
    lastpage.value = query.users.last_page_url;
    nextpage.value = query.users.next_page_url;
    previouspage.value = query.users.prev_page_url;
    totalPages.value = query.users.last_page;
    currentPage.value = query.users.current_page;
    window.addEventListener('resize', handleResize);
    handleResize();
});
</script>

<template>
    <Head title="Admin Dashboard" />

    <AdminAuthenticatedLayout>
        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">Users
                <NavLink :href="route('admin.users.add')" :active="route().current('admin.users.add')">
                    + Add User
                </NavLink>
            </h2>
        </template>

        <div v-if="status" class="mb-4 font-medium text-sm text-green-600">
            {{ status }}
        </div>

        {{ page.props.add }}

        <div v-if="errorMsg" class="mb-4 font-medium text-sm text-red-600">
            {{ errorMsg }}
        </div>

        <div class="py-12">

            <div v-if="flashMessage" class="max-w-7xl mx-auto sm:px-6 lg:px-8 font-bold text-red-600">
                <div class="form-row mb-6">
                    <div class="col-md-6">
                        <h4>{{ flashMessage }}</h4>
                    </div>
                </div>
            </div>

            <div class="container mx-auto sm:px-6 lg:px-8">
                <div class="content-box sm:rounded-lg table-layout">
                    <label for="perPageSelect">Per Page </label>
                    <select id="perPageSelect" class="sm:mx-3 sm:mb-6" v-model="perPage" @change="changePerPage">
                        <option v-for="option in perPageOptions" :key="option" :value="option">
                            {{ option }}
                        </option>
                    </select>
                    <nav class="flex" style="width:200px;display: inline-block;float:right;">
                        <ul class="pagination" style="float:right;">
                            <li class="page-item">
                                <a class="page-link" :href="firstpage" v-if="firstpage && currentPage != totalPages"><span aria-hidden="true">&laquo;</span></a>
                            </li>
                            <li class="page-item">
                                <a class="page-link" :href="previouspage + '&per_page='+perPage" v-if="previouspage">Prev</a>
                            </li>
                            <li class="page-item" style="width: 80px;text-align: center;">
                                <a class="page-link"> {{ currentPage }} of {{ totalPages }}</a>
                            </li>
                            <li class="page-item">
                                <a class="page-link" :href="nextpage + '&per_page='+perPage" v-if="nextpage">Next</a>
                            </li>
                            <li class="page-item">
                                <a class="page-link" :href="lastpage" v-if="lastpage && currentPage != totalPages"><span aria-hidden="true">&raquo;</span></a>
                            </li>
                        </ul>
                    </nav>
                    <div v-if="loading">Loading...</div>
                    <table v-else-if="users && users.length" class="table table-striped table-responsive">
                        <thead>
                            <tr>
                                <th @click="sortBy('name')" class="cursor-pointer">Name</th>
                                <th @click="sortBy('email')" class="cursor-pointer">Email</th>
                                <th v-if="!isMobile" @click="sortBy('company')" class="cursor-pointer">Company</th>
                                <th v-if="!isMobile" @click="sortBy('phone')" class="cursor-pointer">Phone</th>
                                <th>Actions</th>
                            </tr>
                        </thead>
                        <tbody>
                            <tr v-for="user in sortedUsers" :key="user.id">
                                <td data-label="Name">{{ user.name }}</td>
                                <td data-label="Email">{{ user.email }}</td>
                                <td data-label="Company" v-if="!isMobile">{{ user.company }}</td>
                                <td data-label="Phone" v-if="!isMobile">{{ user.phone }}</td>
                                <td data-label="Action">
                                    <div class="action-inner">
                                        <button @click="editUser(user)"><i class="fa fa-pen text-green-600"></i> </button>
                                        <button class="mx-3" @click="deleteUser(user)"> <i class="fa fa-trash text-red-600"></i></button>
                                    </div>
                                </td>
                            </tr>
                        </tbody>
                    </table>
                    <p v-else>No users found.</p>
                </div>
            </div>
        </div>
    </AdminAuthenticatedLayout>
</template>
